\name{bruto}
\alias{bruto}
\title{
  Fit an Additive Spline Model by Adaptive Backfitting
}
\description{
  Fit an additive spline model by adaptive backfitting.
}
\usage{
bruto(x, y, w, wp, dfmax, cost, maxit.select, maxit.backfit, 
      thresh = 0.0001, trace.bruto = FALSE, start.linear = TRUE,
      fit.object, \dots)
}
\arguments{
  \item{x}{a matrix of numeric predictors (does not include the column
    of 1s).}
  \item{y}{a vector or matrix of responses.}
  \item{w}{optional observation weight vector.}
  \item{wp}{optional weight vector for each column of \code{y}; the RSS
    and GCV criteria use a weighted sum of squared residuals.}
  \item{dfmax}{a vector of maximum df (degrees of freedom) for each
    term.}
  \item{cost}{cost per degree of freedom; default is 2.}
  \item{maxit.select}{maximum number of iterations during the selection
    stage.}
  \item{maxit.backfit}{maximum number of iterations for the final
    backfit stage (with fixed lambda).} 
  \item{thresh}{convergence threshold (default is 0.0001); iterations
    cease when the relative change in GCV is below this threshold.} 
  \item{trace.bruto}{logical flag.  If \code{TRUE} (default) a progress
    report is printed during the fitting.}
  \item{start.linear}{logical flag.  If \code{TRUE} (default), the model
    starts with the linear fit.}
  \item{fit.object}{This the object returned by \code{bruto()}; if
    supplied, the same model is fit to the presumeably new \code{y}.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  A multiresponse additive model fit object of class \code{"bruto"} is
  returned.  The model is fit by adaptive backfitting using smoothing
  splines.  If there are \code{np} columns in \code{y}, then \code{np}
  additive models are fit, but the same amount of smoothing (df) is 
  used for  each term.  The procedure chooses between \code{df = 0}
  (term omitted), \code{df = 1} (term linear) or \code{df > 0} (term
  fitted by smoothing spline).  The model selection is based on an
  approximation to the  GCV criterion, which is used at each step of the
  backfitting procedure.  Once the selection process stops, the model is
  backfit using the chosen amount of smoothing.

  A bruto object has the following components of interest:
  \item{lambda}{a vector of chosen smoothing parameters, one for each
    column of \code{x}.}
  \item{df}{the df chosen for each column of \code{x}.}
  \item{type}{a factor with levels \code{"excluded"}, \code{"linear"} or
    \code{"smooth"}, indicating the status of each column of \code{x}.}
  \item{gcv.select gcv.backfit df.select}{The sequence of gcv values and
    df selected during the execution of the function.}
  \item{nit}{the number of iterations used.}
  \item{fitted.values}{a matrix of fitted values.}
  \item{residuals}{a matrix of residuals.}
  \item{call}{the call that produced this object.}
}
\references{
  Trevor Hastie and Rob Tibshirani,
  \emph{Generalized Additive Models},
  Chapman and Hall, 1990 (page 262).

  Trevor Hastie, Rob Tibshirani and Andreas Buja
  ``Flexible Discriminant Analysis by Optimal Scoring''
  AT&T Bell Laboratories Technical Memorandum, February 1993.
}
\seealso{
  \code{\link{predict.bruto}}
}
\examples{
data(trees)
fit1 <- bruto(trees[,-3], trees[3])
fit1$type
fit1$df
## examine the fitted functions
par(mfrow=c(1,2), pty="s")
Xp <- matrix(sapply(trees[1:2], mean), nrow(trees), 2, byrow=TRUE)
for(i in 1:2) {
  xr <- sapply(trees, range)
  Xp1 <- Xp; Xp1[,i] <- seq(xr[1,i], xr[2,i], len=nrow(trees))
  Xf <- predict(fit1, Xp1)
  plot(Xp1[ ,i], Xf, xlab=names(trees)[i], ylab="", type="l")
}
}
% Converted by Sd2Rd version 0.3-3.
\keyword{smooth}

\eof
\name{confusion}
\alias{confusion}
\alias{confusion.default}
\alias{confusion.list}
\alias{confusion.fda}
\title{Confusion Matrices}
\description{
  Compute the confusion matrix between two factors, or for an fda or
  mda object.
}
\usage{
\method{confusion}{default}(object, true, \dots)
\method{confusion}{fda}(object, data, \dots)
}
\arguments{
  \item{object}{the predicted factor, or an fda or mda model object.}
  \item{true}{the true factor.}
  \item{data}{a data frame (list) containing the test data.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\details{
  This is a generic function.
}
\value{
  For the default method essentially \code{table(object, true)}, but
  with some useful attribute(s).
}
\seealso{
  \code{\link{fda}},
  \code{\link{predict.fda}}
}
\examples{
data(iris)
irisfit <- fda(Species ~ ., data = iris)
confusion(predict(irisfit, iris), iris$Species)
##            Setosa Versicolor Virginica 
##     Setosa     50          0         0
## Versicolor      0         48         1
##  Virginica      0          2        49
## attr(, "error"):
## [1] 0.02
}
% Converted by Sd2Rd version 0.3-3.
\keyword{category}

\eof
\name{fda}
\alias{fda}
\alias{coef.fda}
\alias{plot.fda}
\alias{print.fda}
\title{Flexible Discriminant Analysis}
\description{
  Flexible discriminant analysis.}
\usage{
fda(formula, data, weights, theta, dimension, eps, method,
    keep.fitted, \dots)
}
\arguments{
  \item{formula}{of the form \code{y~x} it describes the response and
    the predictors.  The formula can be more complicated, such as
    \code{y~log(x)+z} etc (see \code{\link{formula}} for more details).
    The response should be a factor representing the response variable,
    or any vector that can be coerced to such (such as a logical
    variable).}
  \item{data}{data frame containing the variables in the formula
    (optional).}
  \item{weights}{an optional vector of observation weights.}
  \item{theta}{an optional matrix of class scores, typically with less
    than \code{J-1} columns.}
  \item{dimension}{The dimension of the solution, no greater than
    \code{J-1}, where \code{J} is the number classes.  Default is
    \code{J-1}.}
  \item{eps}{a threshold for small singular values for excluding
    discriminant variables; default is \code{.Machine$double.eps}.}
  \item{method}{regression method used in optimal scaling.  Default is
    linear regression via the function \code{polyreg}, resulting in
    linear discriminant analysis.  Other possibilities are \code{mars}
    and \code{bruto}.  For Penalized Discriminant analysis
    \code{gen.ridge} is appropriate.}
  \item{keep.fitted}{a logical variable, which determines whether the
    (sometimes large) component \code{"fitted.values"} of the \code{fit}
    component of the returned fda object should be kept.  The default is
    \code{TRUE} if \code{n * dimension < 1000}.}
  \item{\dots}{additional arguments to \code{method}.}
}
\value{
  an object of class \code{"fda"}.  Use \code{predict} to extract
  discriminant variables, posterior probabilities or predicted class
  memberships.  Other extractor functions are \code{coef},
  \code{confusion} and \code{plot}.

  The object has the following components:
  \item{percent.explained}{the percent between-group variance explained
    by each dimension (relative to the total explained.)}
  \item{values}{optimal scaling regresssion sum-of-squares for each
    dimension (see reference).  The usual discriminant analysis
    eigenvalues are given by \code{values / (1-values)}, which are used
    to define \code{percent.explained}.}
  \item{means}{class means in the discriminant space.  These are also
    scaled versions of the final theta's or class scores, and can be
    used in a subsequent call to \code{fda} (this only makes sense if
    some columns of theta are omitted---see the references).} 
  \item{theta.mod}{(internal) a class scoring matrix which allows
    \code{predict} to work properly.}
  \item{dimension}{dimension of discriminant space.}
  \item{prior}{class proprotions for the training data.}
  \item{fit}{fit object returned by \code{method}.}
  \item{call}{the call that created this object (allowing it to be
    \code{update}-able)}
  \item{confusion}{confusion matrix when classifying the training data.}

  The \code{method} functions are required to take arguments \code{x}
  and \code{y} where both can be matrices, and should produce a matrix
  of \code{fitted.values} the same size as \code{y}.  They can take
  additional arguments \code{weights} and should all have a \code{\dots}
  for safety sake.  Any arguments to \code{method} can be passed on via
  the \code{\dots} argument of \code{fda}.  The default method
  \code{\link{polyreg}} has a \code{degree} argument which allows
  polynomial regression of the required total degree.  See the
  documentation for \code{\link{predict.fda}} for further requirements
  of \code{method}.
}
\note{
  This software it is not well-tested, we would like to hear of any
  bugs.}
\author{
  Trevor Hastie and Robert Tibshirani
}
\seealso{
  \code{\link{predict.fda}},
  \code{\link{mars}},
  \code{\link{bruto}},
  \code{\link{polyreg}},
  \code{\link{softmax}},
  \code{\link{confusion}},
  %% \code{\link{coefficients.fda}}
}
\references{
  ``Flexible Disriminant Analysis by Optimal Scoring''  by Hastie,
  Tibshirani and Buja, 1994, JASA, 1255-1270.

  ``Penalized Discriminant Analysis'' by Hastie, Buja and Tibshirani,
  Annals of Statistics, 1995 (in press).
}
\examples{
data(iris)
irisfit <- fda(Species ~ ., data = iris)
irisfit
## fda(formula = Species ~ ., data = iris)
##
## Dimension: 2 
##
## Percent Between-Group Variance Explained:
##     v1     v2 
##  99.12 100.00 
##
## Degrees of Freedom (per dimension): 5 
##
## Training Misclassification Error: 0.02 ( N = 150 )

confusion(irisfit, iris)
##            Setosa Versicolor Virginica 
##     Setosa     50          0         0
## Versicolor      0         48         1
##  Virginica      0          2        49
## attr(, "error"):
## [1] 0.02

plot(irisfit)

coef(irisfit)
##           [,1]        [,2]
## [1,] -2.126479 -6.72910343
## [2,] -0.837798  0.02434685
## [3,] -1.550052  2.18649663
## [4,]  2.223560 -0.94138258
## [5,]  2.838994  2.86801283

marsfit <- fda(Species ~ ., data = iris, method = mars)
marsfit2 <- update(marsfit, degree = 2)
marsfit3 <- update(marsfit, theta = marsfit$means[, 1:2]) 
## this refits the model, using the fitted means (scaled theta's)
## from marsfit to start the iterations
}
\keyword{classif}
% Converted by Sd2Rd version 0.3-3.

\eof
\name{gen.ridge}
\alias{gen.ridge}
\alias{predict.gen.ridge}
\title{Penalized Regression}
\description{
  Perform a penalized regression, as used in penalized discriminant
  analysis.
}
\usage{
gen.ridge(x, y, weights, lambda=1, omega, df, \dots)
}
\arguments{
  \item{x, y, weights}{the x and y matrix and possibly a weight vector.}
  \item{lambda}{the shrinkage penalty coefficient.}
  \item{omega}{a penalty object; omega is the eigendecomposition of
    the penalty matrix, and need not have full rank.  By default,
    standard ridge is used.}
  \item{df}{an alternative way to prescribe lambda, using the notion
    of equivalent degrees of freedom.}
  \item{\dots}{currently not used.}
}
\value{
  A generalized ridge regression, where the coefficients are penalized
  according to omega.  See the function definition for further details.
  No functions are provided for producing one dimensional penalty
  objects (omega).
  %%FIXME
  %% \code{\link{laplacian}()} creates a two dimensional penalty
  %% object, suitable for (small) images.
}
%% \seealso{
%%   \code{\link{laplacian}}
%% }
% Converted by Sd2Rd version 0.3-3.
\keyword{regression}

\eof
\name{glass}
\alias{glass}
\title{Glass Identification Database}
\description{
  The \code{glass} data frame has 214 observations and 10 variables,
  representing glass fragments.
}
\usage{data(glass)}
\format{
  This data frame contains the following columns:
  \describe{
    \item{RI}{refractive index}
    \item{Na}{weight percent in corresponding oxide}
    \item{Mg}{weight percent in corresponding oxide}
    \item{Al}{weight percent in corresponding oxide}
    \item{Si}{weight percent in corresponding oxide}
    \item{K}{weight percent in corresponding oxide}
    \item{Ca}{weight percent in corresponding oxide}
    \item{Ba}{weight percent in corresponding oxide}
    \item{Fe}{weight percent in corresponding oxide}
    \item{Type}{Type of glass:
      \describe{
	\item{1}{building\_windows\_float\_processed,}
	\item{2}{building\_windows\_non\_float\_processed,}
	\item{3}{vehicle\_windows\_float\_processed,}
	\item{4}{vehicle\_windows\_non\_float\_processed (none in this
	  database),}
	\item{5}{containers,}
	\item{6}{tableware,}
	\item{7}{headlamps}
      }
    }
  }
}
\source{
  P. M. Murphy and D. W. Aha (1999),
  UCI Repository of Machine Learning Databases,
  \url{ftp://ics.uci.edu/pub/machine-learning-databases}
}
\keyword{datasets}

\eof
\name{mars}
\alias{mars}
\title{Multivariate Additive Regression Splines}
\description{
  Multivariate additive regression splines.
}
\usage{
mars(x, y, w, wp, degree, nk, penalty, thresh, prune, trace.mars,
     forward.step, prevfit, \dots)
}
\arguments{
  \item{x}{a matrix containing the independent variables.}
  \item{y}{a vector containing the response variable, or in the case of
    multiple responses, a matrix whose columns are the response values
    for each variable.}
  \item{w}{an optional vector of observation weights.}
  \item{wp}{an optional vector of response weights.}
  \item{degree}{an optional integer specifying maximum interaction
    degree (default is 1).}
  \item{nk}{an optional integer specifying the maximum number of model
    terms.}
  \item{penalty}{an optional value specifying the cost per degree of
    freedom charge (default is 2).}
  \item{thresh}{an optional value specifying forward stepwise stopping
    threshold (default is 0.001).}
  \item{prune}{an optional logical value specifying whether the model
    should be pruned in a backward stepwise fashion (default is
    \code{TRUE}).}
  \item{trace.mars}{an optional logical value specifying whether info
    should be printed along the way (default is \code{FALSE}).}
  \item{forward.step}{an optional logical value specifying whether
    forward stepwise process should be carried out (default is
    \code{TRUE}).}
  \item{prevfit}{optional data structure from previous fit.  To see the
    effect of changing the penalty paramater, one can use prevfit with
    \code{forward.step = FALSE}.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  An object of class \code{"mars"}, which is a list with the following
  components:

  \item{call}{call used to \code{mars}.}
  \item{all.terms}{term numbers in full model.  \code{1} is the constant
    term.  Remaining terms are in pairs (\code{2 3}, \code{4 5}, and so
    on).  \code{all.terms} indicates nonsingular set of terms.}
  \item{selected.terms}{term numbers in selected model.}
  \item{penalty}{the input penalty value.}
  \item{degree}{the input degree value.}
  \item{thresh}{the input threshold value.}
  \item{gcv}{gcv of chosen model.}
  \item{factor}{matrix with \eqn{ij}-th element equal to 1 if term
    \eqn{i} has a factor of the form \eqn{x_j > c}, equal to \eqn{-1} if
    term \eqn{i} has a factor of the form \eqn{x_j \le c}, and to 0 if
    \eqn{xj} is not in term \eqn{i}.}
  \item{cuts}{matrix with \eqn{ij}-th element equal to the cut point
    \eqn{c} for variable \eqn{j} in term \eqn{i}.}
  \item{residuals}{residuals from fit.}
  \item{fitted}{fitted values from fit.}
  \item{lenb}{length of full model.}
  \item{coefficients}{least squares coefficients for final model.}
  \item{x}{the input x matrix.}
}
\note{
  This function was coded from scratch, and did not use any of
  Friedman's mars code.  It gives quite similar results to  Friedman's
  program in our tests, but not exactly the same results.  We have not 
  implemented Friedman's anova decomposition nor are categorical
  predictors handled properly yet.  Our version does handle multiple
  response variables, however.  As it is not well-tested, we would like
  to hear of any bugs.}
\author{
  Trevor Hastie and Robert Tibshirani
}
\references{
  J. Friedman, ``Multivariate Additive Regression Splines''.
  \emph{Annals of Statistics}, 1991.
}
\seealso{
  \code{\link{predict.mars}},
  \code{\link{model.matrix.mars}}
}
\examples{
data(trees)
fit1 <- mars(trees[,-3], trees[3])
showcuts <- function(obj)
{
  tmp <- obj$cuts[obj$sel, ]
  dimnames(tmp) <- list(NULL, names(trees)[-3])
  tmp
}
showcuts(fit1)

## examine the fitted functions
par(mfrow=c(1,2), pty="s")
Xp <- matrix(sapply(trees[1:2], mean), nrow(trees), 2, byrow=TRUE)
for(i in 1:2) {
  xr <- sapply(trees, range)
  Xp1 <- Xp; Xp1[,i] <- seq(xr[1,i], xr[2,i], len=nrow(trees))
  Xf <- predict(fit1, Xp1)
  plot(Xp1[ ,i], Xf, xlab=names(trees)[i], ylab="", type="l")
}
}
% Converted by Sd2Rd version 0.3-3.
\keyword{smooth}

\eof
\name{mda-internal}
\alias{contr.fda}
\alias{fix.theta}
\alias{kmeans.start}
\alias{laplacian}
\alias{llmult}
\alias{lvq.start}
\alias{make.dumpdata.mda}
\alias{meanPenalty}
\alias{mda.fit}
\alias{mda.means}
\alias{polybasis}
\alias{pplot}
\alias{pplot4}
\alias{shrink}
\alias{shrink.mda}
\alias{transformPenalty}
\title{Internal mda Functions}
\description{Internal mda functions.}
\details{
  These are not to be called by the user.
}
\keyword{internal}

\eof
\name{mda}
\alias{mda}
\alias{print.mda}
\title{Mixture Discriminant Analysis}
\description{
  Mixture discriminant analysis.
}
\usage{
mda(formula, data, subclasses, sub.df, tot.df, dimension, eps,
    iter, weights, method, keep.fitted, trace, \dots)
}
\arguments{
  \item{formula}{of the form \code{y~x} it describes the response and
    the predictors.  The formula can be more complicated, such as
    \code{y~log(x)+z} etc (see \code{\link{formula}} for more details).
    The response should be a factor representing the response variable,
    or any vector that can be coerced to such (such as a logical
    variable).}
  \item{data}{data frame containing the variables in the formula
    (optional).}
  \item{subclasses}{Number of subclasses per class, default is 3.  Can be
    a vector with a number for each class.}
  \item{sub.df}{If subclass centroid shrinking is performed, what is the
    effective degrees of freedom of the centroids per class.  Can be a
    scalar, in which case the same number is used for each class, else a
    vector.}
  \item{tot.df}{The total df for all the centroids can be specified
    rather than separately per class.}
  \item{dimension}{The dimension of the reduced model.  If we know our
    final model will be confined to a discriminant subspace (of the
    subclass centroids), we can specify this in advance and have the EM
    algorithm operate in this subspace.}
  \item{eps}{A numerical threshold for automatically truncating the
    dimension.}
  \item{iter}{A limit on the total number of iterations,  default is 5.}
  \item{weights}{\emph{NOT} observation weights!  This is a special
    weight structure, which for each class assigns a weight (prior
    probability) to each of the observations in that class of belonging
    to one of the subclasses.  The default is provided by a call to
    \code{mda.start(x, g, subclasses, trace, \dots)} (by this time
    \code{x} and \code{g} are known).  See the help for
    \code{\link{mda.start}}.  Arguments for \code{mda.start} can be
    provided via the \code{\dots} argument to mda, and the
    \code{weights} argument need never be accessed.  A previously fit
    mda object can be supplied, in which case the final subclass
    \code{responsibility} weights are used for \code{weights}.  This 
    allows the iterations from a previous fit to be continued.}
  \item{method}{regression method used in optimal scaling.  Default is
    linear regression via the function \code{polyreg}, resulting in the
    usual mixture model.  Other possibilities are \code{mars} and 
    \code{bruto}.  For penalized mixture discriminant models
    \code{gen.ridge} is appropriate.}
  \item{keep.fitted}{a logical variable, which determines whether the
    (sometimes large) component \code{"fitted.values"} of the \code{fit}
    component of the returned \code{mda} object should be kept.  The
    default is \code{TRUE} if \code{n * dimension < 1000}.} 
  \item{trace}{if \code{TRUE}, iteration information is printed.  Note
    that the deviance reported is for the posterior class likelihood,
    and not the full likelihood, which is used to drive the EM algorithm
    under \code{mda}.  In general the latter is not available.}
  \item{\dots}{additional arguments to \code{mda.start} and to
    \code{method}.}
}
\value{
  An object of class \code{c("mda", "fda")}.  The most useful extractor
  is \code{predict}, which can make many types of predictions from this
  object.  It can also be plotted, and any functions useful for fda
  objects will work here too, such as \code{confusion} and \code{coef}.

  The object has the following components:
  \item{percent.explained}{the percent between-group variance explained
    by each dimension (relative to the total explained.)}
  \item{values}{optimal scaling regresssion sum-of-squares for each
    dimension (see reference).}
  \item{means}{subclass means in the discriminant space.  These are also
    scaled versions of the final theta's or class scores, and can be
    used in a subsequent call to \code{mda} (this only makes sense if
    some columns of theta are omitted---see the references)}
  \item{theta.mod}{(internal) a class scoring matrix which allows
    \code{predict} to work properly.}
  \item{dimension}{dimension of discriminant space.}
  \item{sub.prior}{subclass membership priors, computed in the fit.  No
    effort is currently spent in trying to keep these above a threshold.}
  \item{prior}{class proprotions for the training data.}
  \item{fit}{fit object returned by \code{method}.}
  \item{call}{the call that created this object (allowing it to be
    \code{update}-able).}
  \item{confusion}{confusion matrix when classifying the training data.}
  \item{weights}{These are the subclass membership probabilities for
    each member of the training set; see the weights argument.}
  \item{assign.theta}{a pointer list which identifies which elements of
    certain lists belong to individual classes.}
  \item{deviance}{The multinomial log-liklihood of the fit.  Even though
    the full log-likelihood drives the iterations, we cannot in general
    compute it because of the flexibility of the \code{method} used.
    The deviance can increase with the iterations, but generally does not.}

  The \code{method} functions are required to take arguments \code{x}
  and \code{y} where both can be matrices, and should produce a matrix
  of \code{fitted.values} the same size as \code{y}.  They can take
  additional arguments \code{weights} and should all have a \code{\dots}
  for safety sake.  Any arguments to method() can be passed on via the
  \code{\dots} argument of \code{mda}.  The default method
  \code{polyreg} has a \code{degree} argument which allows polynomial
  regression of the required total degree.  See the documentation for
  \code{\link{predict.fda}} for further requirements of \code{method}.

  The function \code{mda.start} creates the starting weights; it takes
  additional arguments which can be passed in via the \code{\dots}
  argument to \code{mda}.  See the documentation for \code{mda.start}.
}
\note{
  This software it is not well-tested, we would like to hear of any
  bugs.
}
\author{
  Trevor Hastie and Robert Tibshirani
}
\seealso{
  \code{\link{predict.mda}},
  \code{\link{mars}},
  \code{\link{bruto}},
  \code{\link{polyreg}},
  \code{\link{gen.ridge}},
  \code{\link{softmax}},
  \code{\link{confusion}}
  %%\code{\link{coef.fda}},
  %%\code{\link{plot.fda}}
}
\references{
  ``Flexible Disriminant Analysis by Optimal Scoring'' by Hastie,
  Tibshirani and Buja, 1994, JASA, 1255-1270.

  ``Penalized Discriminant Analysis'' by Hastie, Buja and Tibshirani,
  Annals of Statistics, 1995 (in press).
    
  ``Discriminant Analysis by Gaussian Mixtures'' by Hastie and
  Tibshirani, 1994, JRSS-B (in press).
}
\examples{
data(iris)
irisfit <- mda(Species ~ ., data = iris)
irisfit
## Call:
## mda(formula = Species ~ ., data = iris)
##
## Dimension: 4
##
## Percent Between-Group Variance Explained:
##     v1     v2     v3     v4
##  96.02  98.55  99.90 100.00
##
## Degrees of Freedom (per dimension): 5
##
## Training Misclassification Error: 0.02 ( N = 150 )
##
## Deviance: 15.102

data(glass)
# random sample of size 100
samp <- c(1, 3, 4, 11, 12, 13, 14, 16, 17, 18, 19, 20, 27, 28, 31,
          38, 42, 46, 47, 48, 49, 52, 53, 54, 55, 57, 62, 63, 64, 65,
          67, 68, 69, 70, 72, 73, 78, 79, 83, 84, 85, 87, 91, 92, 94,
          99, 100, 106, 107, 108, 111, 112, 113, 115, 118, 121, 123,
          124, 125, 126, 129, 131, 133, 136, 139, 142, 143, 145, 147,
          152, 153, 156, 159, 160, 161, 164, 165, 166, 168, 169, 171,
          172, 173, 174, 175, 177, 178, 181, 182, 185, 188, 189, 192,
          195, 197, 203, 205, 211, 212, 214) 
glass.train <- glass[samp,]
glass.test <- glass[-samp,]
glass.mda <- mda(Type ~ ., data = glass.train)
predict(glass.mda, glass.test, type="post") # abbreviations are allowed
confusion(glass.mda,glass.test)
}
\keyword{classif}
% Converted by Sd2Rd version 0.3-3.

\eof
\name{mda.start}
\alias{mda.start}
\title{Initialization for Mixture Discriminant Analysis}
\description{Provide starting weights for the \code{mda} function which
  performs discriminant analysis by gaussian mixtures.}
\usage{
mda.start(x, g, subclasses = 3, trace.mda.start = FALSE,
          start.method = c("kmeans", "lvq"), tries = 5,
          criterion = c("misclassification", "deviance"), \dots)
}
\arguments{
  \item{x}{The x data, or an mda object.}
  \item{g}{The response vector g.}
  \item{subclasses}{number of subclasses per class, as in \code{mda}.}
  \item{trace.mda.start}{Show results of each iteration.}
  \item{start.method}{Either \code{"kmeans"} or \code{"lvq"}.  The
    latter requires package \bold{class} (from the \bold{VR} package
    bundle.}
  \item{tries}{Number of random starts.}
  \item{criterion}{By default, classification errors on the training
    data.  Posterior deviance is also an option.}
  \item{\dots}{arguments to be passed to the mda fitter when using
    posterior deviance.}
}
\value{
  A list of weight matrices, one for each class.
}
% Converted by Sd2Rd version 0.3-3.
\keyword{classif}

\eof
\name{model.matrix.mars}
\alias{model.matrix.mars}
\title{Produce a Design Matrix from a `mars' Object}
\description{Produce a design matrix from a `mars' object.}
\usage{
model.matrix.mars(object, x, which, full = FALSE, \dots)
}
\arguments{
  \item{object}{a mars object.}
  \item{x}{optional argument; if supplied, the mars basis functions are
    evaluated at these new observations.}
  \item{which}{which columns should be used. The default is to use the
    columns described by the component \code{selected.terms} on
    \code{object}.}
  \item{full}{if \code{TRUE} the entire set of columns are selected,
    even redundant ones.  This is used for updating a mars fit.}
  \item{\dots}{further arguments to be passed from or to methods.}
}
\value{
  A model matrix corresponding to the selected columns.
}
\seealso{
  \code{\link{mars}},
  \code{\link{predict.mars}}
}
% Converted by Sd2Rd version 0.3-3.
\keyword{models}

\eof
\name{polyreg}
\alias{polyreg}
\alias{predict.polyreg}
\title{Polynomial Regression}
\description{
  Simple minded polynomial regression.
}
\usage{
polyreg(x, y, w, degree = 1, monomial = FALSE, \dots)
}
\arguments{
  \item{x}{predictor matrix.}
  \item{y}{response matrix.}
  \item{w}{optional (positive) weights.}
  \item{degree}{total degree of polynomial basis (default is 1).}
  \item{monomial}{If \code{TRUE} a monomial basis is used (no cross
    terms).  Default is \code{FALSE}.}
  \item{\dots}{currently not used.}
}
\value{
  A polynomial regression fit, containing the essential ingredients for
  its \code{predict} method.
}
%%\seealso{
%%  \code{\link{predict.polyreg}}
%%}
% Converted by Sd2Rd version 0.3-3.
\keyword{regression}

\eof
\name{predict.bruto}
\alias{predict.bruto}
\title{Predict method for BRUTO Objects}
\description{
  Predicted values based on `bruto' additive spline models which are fit
  by adaptive backfitting.
}
\usage{
\method{predict}{bruto}(object, x, type=c("fitted", "terms"), \dots)
}
\arguments{
  \item{object}{a fitted bruto object}
  \item{x}{values at which predictions are to be made.}
  \item{type}{if type is \code{"fitted"}, the fitted values are
    returned.  If type is \code{"terms"}, a list of fitted terms is
    returned, each with an \code{x} and \code{y} component.  These can
    be used to show the fitted functions.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  Either a fit matrix or a list of fitted terms.
}
\seealso{
  \code{\link{bruto}},
  \code{\link{predict}}
}
\examples{
data(trees)
fit1 <- bruto(trees[,-3], trees[3])
fitted.terms <- predict(fit1, as.matrix(trees[,-3]), type = "terms")
par(mfrow=c(1,2), pty="s")
for(tt in fitted.terms) plot(tt, type="l")
}
% Converted by Sd2Rd version 0.3-3.
\keyword{smooth}

\eof
\name{predict.fda}
\alias{predict.fda}
\title{Classify by Flexible Discriminant Analysis}
\description{
  Classify observations in conjunction with \code{fda}.
}
\usage{
\method{predict}{fda}(object, x, type, prior, dimension, \dots)
}
\arguments{
  \item{object}{an object of class \code{"fda"}.}
  \item{x}{new data at which to make predictions.  If missing, the
    training data is used.}
  \item{type}{kind of predictions: \code{type = "class"} (default)
    produces a fitted factor, \code{type = "variates"} produces a matrix
    of discriminant variables, \code{type = "posterior"} produces a
    matrix of posterior probabilities (based on a gaussian assumption),
    and \code{type = "hierarchical"} produces the predicted class in
    sequence for models of all dimensions.}
  \item{prior}{the prior probabability vector for each class; the
    default is the training sample proportions.}
  \item{dimension}{the dimension of the space to be used, no larger
    than the dimension component  of \code{object}.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  An appropriate object depending on \code{type}. \code{object} has a
  component \code{fit} which is regression fit produced by the
  \code{method} argument to \code{fda}.  There should be a
  \code{predict} method for this object which is invoked.  This method
  should itself take as input \code{object} and optionally \code{x}.
}
\seealso{
  \code{\link{fda}},
  \code{\link{mars}},
  \code{\link{bruto}},
  \code{\link{polyreg}},
  \code{\link{softmax}},
  \code{\link{confusion}}
}
\examples{
data(iris)
irisfit <- fda(Species ~ ., data = iris)
irisfit
## Call:
## fda(x = iris$x, g = iris$g)
## 
## Dimension: 2 
##
## Percent Between-Group Variance Explained:
##     v1  v2 
##  99.12 100
confusion(predict(irisfit, iris), iris$Species)
##            Setosa Versicolor Virginica
##     Setosa     50          0         0
## Versicolor      0         48         1
##  Virginica      0          2        49
## attr(, "error"):
## [1] 0.02
}
% Converted by Sd2Rd version 0.3-3.
\keyword{classif}

\eof
\name{predict.mars}
\alias{predict.mars}
\title{Predict method for MARS Objects}
\description{
  Predicted values based on `mars' multivariate adaptive regression
  spline models.
}
\usage{
\method{predict}{mars}(object, x, \dots)
}
\arguments{
  \item{object}{an object of class \code{"mars"}.}
  \item{x}{values at which predictions are to be made.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  the fitted values.
}
\seealso{
  \code{\link{mars}},
  \code{\link{predict}},
  \code{\link{model.matrix.mars}}
}
%%\examples{
%%## see help for mars()
%%}
% Converted by Sd2Rd version 0.3-3.
\keyword{smooth}

\eof
\name{predict.mda}
\alias{predict.mda}
\title{Classify by Mixture Discriminant Analysis}
\description{
  Classify observations in conjunction with \code{mda}.
}
\usage{
\method{predict}{mda}(object, x, type, prior, dimension, g, \dots)
}
\arguments{
  \item{object}{a fitted mda object.}
  \item{x}{new data at which to make predictions.  If missing, the
    training data is used.}
  \item{type}{kind of predictions: \code{type = "class"} (default)
    produces a fitted factor, \code{type = "variates"} produces a matrix
    of discriminant variables (note that the maximal dimension is
    determined by the number of subclasses), \code{type = "posterior"}
    produces a matrix of posterior probabilities (based on a gaussian
    assumption), \code{type = "hierarchical"} produces the predicted
    class in sequence for models of dimensions specified by
    \code{dimension} argument.}
  \item{prior}{the prior probabability vector for each class; the
    default is the training sample proportions.}
  \item{dimension}{the dimension of the space to be used, no larger
    than the dimension component of \code{object}, and in general less
    than the number of subclasses.  \code{dimension} can be a vector for
    use with \code{type = "hierarchical"}.}
  \item{g}{???}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{
  An appropriate object depending on \code{type}.  \code{object} has a
  component \code{fit} which is regression fit produced by the
  \code{method} argument to \code{mda}.  There should be a
  \code{predict} method for this object which is invoked.  This method
  should itself take as input \code{object} and optionally \code{x}.
}
\seealso{
  \code{\link{mda}},
  \code{\link{fda}},
  \code{\link{mars}},
  \code{\link{bruto}},
  \code{\link{polyreg}},
  \code{\link{softmax}},
  \code{\link{confusion}}
}
\examples{
data(glass)
samp <- sample(1:nrow(glass), 100)
glass.train <- glass[samp,]
glass.test <- glass[-samp,]
glass.mda <- mda(Type ~ ., data = glass.train)
predict(glass.mda, glass.test, type = "post") # abbreviations are allowed
confusion(glass.mda, glass.test)
}
\keyword{classif}
% Converted by Sd2Rd version 0.3-3.

\eof
\name{softmax}
\alias{softmax}
\title{Find the Maximum in Each Row of a Matrix}
\description{Find the maximum in each row of a matrix.}
\usage{
softmax(x, gap = FALSE)
}
\arguments{
  \item{x}{a numeric matrix.}
  \item{gap}{if \code{TRUE}, the difference between the largest and
    next largest column is returned.}
}
\value{
  A factor with levels the column labels of \code{x} and values the
  columns corresponding to the maximum column. If \code{gap = TRUE} a
  list is returned, the second component of which is the difference
  between the largest and next largest column of \code{x}.
}
\seealso{
  \code{\link{predict.fda}},
  \code{\link{confusion}},
  \code{\link{fda}} 
}
\examples{
data(iris)
irisfit <- fda(Species ~ ., data = iris)
posteriors <- predict(irisfit, type = "post")
confusion(softmax(posteriors), iris[, "Species"])
}
% Converted by Sd2Rd version 0.3-3.
\keyword{utilities}

\eof
